(ns wanijo.schema.routes
  (:require [compojure.core :refer [defroutes GET POST]]
            [ring.util.anti-forgery :refer [anti-forgery-field]]
            [ring.util.response :as resp]
            [hiccup.form :as hform]
            [wanijo.domain.schema :as domain-schema]
            [wanijo.view.page :as page]
            [wanijo.view.forms :as forms]))

(def new-schema-form
  {:fields {:schema-name {:label "Nimi"
                          :required true
                          :spec :wanijo.domain.schema/name}}})

(defn- overview! [req]
  (let [session (:session req)
        ident (:ident session)
        schemas (domain-schema/all-created-by! ident)]
    (page/layout!
     :session session
     :content
     [[:h1 "Ali jaki ijo"]
      [:table
       [:thead
        [:tr
         [:th "Nimi"]
         [:th "Tenpo kama"]]]
       [:tbody
        (for [schema schemas]
          [:tr
           [:td (:name schema)]
           [:td (:created_at schema)]])]]
      [:h1 "Pali sin e jaki ijo"]
      (hform/form-to
       [:post "/schema/new"]
       (forms/field new-schema-form :schema-name req)
       (hform/submit-button "Pali")
       (anti-forgery-field))])))

(defn- new! [req]
  (if (forms/valid? new-schema-form req)
    (resp/redirect "/schema")
    (overview! req)))

(defroutes schema-routes
  (GET "/schema" [] overview!)
  (POST "/schema/new" [] new!))
